Usage — django-smartspaceless 0.1 documentation

# Usage

Load the template tag in a template. Run the tag with an opening and closing tag.

    {% extends "base.html" %}

    {% load smartspaceless_tags %}

    {% block content %}

        {% smartspaceless %}
        <p><a href="#">Link 1</a></p>
        <p><a href="#">Link 2</a> <a href="#">Link 3</a></p>
        {% endsmartspaceless %}

    {% endblock %}

Result:

    <p><a href="#">Link 1</a></p><p><a href="#">Link 2</a> <a href="#">Link 3</a></p>